@@ -50,12 +50,6 @@ module Diagrams.Backend.CmdLine
   , diagramAnimOpts
   , fpu
 
-    -- ** Loop options
-  , DiagramLoopOpts(..)
-  , diagramLoopOpts
-  , loop
-  , src
-
     -- * Parsing
   , Parseable(..)
   , readHexColor
@@ -70,19 +64,17 @@ module Diagrams.Backend.CmdLine
     -- ** helper functions for implementing @mainRender@
   , defaultAnimMainRender
   , defaultMultiMainRender
-  , defaultLoopRender
   ) where
 
 import           Control.Lens              (Lens', makeLenses, (&), (.~), (^.))
 import           Diagrams.Animation
 import           Diagrams.Attributes
 import           Diagrams.Core             hiding (output)
-import           Diagrams.Util
 
 import           Options.Applicative
 import           Options.Applicative.Types (readerAsk)
 
-import           Control.Monad             (forM_, forever, unless, when)
+import           Control.Monad             (forM_)
 
 -- MonadFail comes from Prelude in base-4.13 and up
 #if !MIN_VERSION_base(4,13,0)
@@ -96,27 +88,12 @@ import           Data.Colour.Names
 import           Data.Colour.SRGB
 import           Data.Data
 import           Data.Functor.Identity
-import           Data.IORef
 import           Data.Kind                 (Type)
-import           Data.List                 (delete)
-import           Data.Maybe                (fromMaybe)
 import           Data.Monoid
 import           Numeric
 
-import           Control.Concurrent        (threadDelay)
-import           System.Directory          (canonicalizePath)
-import           System.Environment        (getArgs, getProgName)
-import           System.Exit               (ExitCode (..))
-import           System.FilePath           (addExtension, dropExtension,
-                                            replaceExtension, splitExtension,
-                                            takeDirectory, takeFileName, (</>))
-import           System.FSNotify           (defaultConfig,
-                                            eventTime, watchDir,
-                                            withManagerConf, confWatchMode, WatchMode(..))
-import           System.FSNotify.Devel     (existsEvents)
-import           System.Info               (os)
-import           System.IO                 (hFlush, stdout)
-import           System.Process            (readProcessWithExitCode)
+import           System.Environment        (getProgName)
+import           System.FilePath           (addExtension, splitExtension)
 
 import           Text.Printf
 
@@ -149,14 +126,6 @@ data DiagramAnimOpts = DiagramAnimOpts
 
 makeLenses ''DiagramAnimOpts
 
--- | Extra options for command-line looping.
-data DiagramLoopOpts = DiagramLoopOpts
-  { _loop     :: Bool            -- ^ Flag to indicate that the program should loop creation.
-  , _src      :: Maybe FilePath  -- ^ File path for the source file to recompile.
-  }
-
-makeLenses ''DiagramLoopOpts
-
 -- | Command line parser for 'DiagramOpts'.
 --   Width is option @--width@ or @-w@.
 --   Height is option @--height@ or @-h@ (note we change help to be @-?@ due to this).
@@ -199,16 +168,6 @@ diagramAnimOpts = DiagramAnimOpts
      <> value 30.0
      <> help "Frames per unit time (for animations)")
 
--- | CommandLine parser for 'DiagramLoopOpts'
---   Loop is @--loop@ or @-l@.
---   Source is @--src@ or @-s@.
-diagramLoopOpts :: Parser DiagramLoopOpts
-diagramLoopOpts = DiagramLoopOpts
-  <$> switch (long "loop" <> short 'l' <> help "Run in a self-recompiling loop")
-  <*> (optional . strOption)
-      ( long "src" <> short 's'
-     <> help "Source file to watch")
-
 -- | A hidden \"helper\" option which always fails.
 --   Taken from Options.Applicative.Extra but without the
 --   short option 'h'.  We want the 'h' for Height.
@@ -277,11 +236,6 @@ instance Parseable DiagramMultiOpts where
 instance Parseable DiagramAnimOpts where
   parser = diagramAnimOpts
 
--- | Parse 'DiagramLoopOpts' using the 'diagramLoopOpts' parser.
-instance Parseable DiagramLoopOpts where
-  parser = diagramLoopOpts
-
-
 -- | Parse @'Colour' Double@ as either a named color from "Data.Colour.Names"
 --   or a hexadecimal color.
 instance Parseable (Colour Double) where
@@ -529,9 +483,8 @@ showDiaList ds = do
 --   be output for each second (unit time) of animation.
 --
 --   This function requires a lens into the structure that the particular backend
---   uses for it's diagram base case.  If @MainOpts (QDiagram b v n Any) ~ DiagramOpts@
---   then this lens will simply be 'output'.  For a backend supporting looping
---   it will most likely be @_1 . output@.  This lens is required because the
+--   uses for its diagram base case.  If @MainOpts (QDiagram b v n Any) ~ DiagramOpts@
+--   then this lens will simply be 'output'.  This lens is required because the
 --   implementation works by modifying the output field and running the base @mainRender@.
 --   Typically a backend can write its @Animation B V@ instance as
 --
@@ -563,86 +516,3 @@ indexize out nDigits i opts = opts & out .~ output'
   where fmt         = "%0" ++ show nDigits ++ "d"
         output'     = addExtension (base ++ printf fmt i) ext
         (base, ext) = splitExtension (opts^.out)
-
-putStrF :: String -> IO ()
-putStrF s = putStr s >> hFlush stdout
-
-defaultLoopRender :: DiagramLoopOpts -> IO ()
-defaultLoopRender opts = when (opts ^. loop) $ do
-  putStrLn "Looping turned on"
-  prog <- getProgName
-  args <- getArgs
-
-  srcPath <- case opts ^. src of
-    Just path -> return path
-    Nothing   -> fromMaybe (error nosrc) <$> findHsFile prog
-      where
-        nosrc = "Unable to find Haskell source file.\n"
-             ++ "Specify source file with '-s' or '--src'"
-  srcPath' <- canonicalizePath srcPath
-
-  sandbox     <- findSandbox []
-  sandboxArgs <- case sandbox of
-    Nothing -> return []
-    Just sb -> do
-      putStrLn ("Using sandbox " ++ takeDirectory sb)
-      return ["-package-db", sb]
-
-  let args'       = delete "-l" . delete "--loop" $ args
-      newProg     = newProgName (takeFileName srcPath) prog
-      timeOfDay   = take 8 . drop 11 . show . eventTime
-
-  withManagerConf defaultConfig $
-    \mgr -> do
-      lock <- newIORef False
-
-      _ <- watchDir mgr (takeDirectory srcPath') (existsEvents (== srcPath'))
-        $ \ev -> do
-          running <- atomicModifyIORef lock ((,) True)
-          unless running $ do
-            putStrF ("Modified " ++ timeOfDay ev ++ " ... ")
-            exitCode <- recompile srcPath' newProg sandboxArgs
-            -- Call the new program without the looping option
-            run newProg args' exitCode
-            atomicWriteIORef lock False
-
-      putStrLn $ "Watching source file " ++ srcPath
-      putStrLn $ "Compiling target: " ++ newProg
-      putStrLn $ "Program args: " ++ unwords args'
-      forever . threadDelay $ case os of
-         -- https://ghc.haskell.org/trac/ghc/ticket/7325
-        "darwin" -> 2000000000
-        _        -> maxBound
-
-recompile :: FilePath -> FilePath -> [String] -> IO ExitCode
-recompile srcFile outFile args = do
-  let ghcArgs = ["--make", srcFile, "-o", outFile] ++ args
-  putStrF "compiling ... "
-  (exit, _, stderr) <- readProcessWithExitCode "ghc" ghcArgs ""
-  when (exit /= ExitSuccess) $ putStrLn ('\n':stderr)
-  return exit
-
--- | On Windows, the next compilation must have a different output
---   than the currently running program.
-newProgName :: FilePath -> String -> String
-newProgName srcFile oldName = case os of
-  "mingw32" ->
-      if oldName == replaceExtension srcFile "exe"
-        then replaceExtension srcFile ".1.exe"
-        else replaceExtension srcFile "exe"
-  _ -> dropExtension srcFile
-
--- | Run the given program with specified arguments, if and only if
---   the previous command returned ExitSuccess.
-run :: String -> [String] -> ExitCode -> IO ()
-run prog args ExitSuccess = do
-  let path = "." </> prog
-  putStrF "running ... "
-  (exit, stdOut, stdErr) <- readProcessWithExitCode path args ""
-  case exit of
-    ExitSuccess   -> putStrLn "done."
-    ExitFailure r -> do
-      putStrLn $ prog ++ " failed with exit code " ++ show r
-      unless (null stdOut) $ putStrLn "stdout:" >> putStrLn stdOut
-      unless (null stdErr) $ putStrLn "stderr:" >> putStrLn stdErr
-run _ _ _ = return ()
