@@ -109,7 +109,7 @@ import           Control.Lens              (Lens', Traversal',
                                             generateSignatures, lensRules,
                                             makeLensesWith, view, (%~), (&),
                                             (.~), (^.))
-import           Data.Default.Class
+import           Data.Default
 import           Data.Maybe                (fromMaybe)
 import           Data.Monoid.Coproduct     (untangle)
 import           Data.Semigroup
